# MessageAction

An action-button (e.g. as in WebPush) in a message

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | **str** | The text the user is shown | [optional] 
**uri** | **str** | the URI to invoke (with context) when selected | [optional] 
**icon** | **str** | the URI to an icon-button (if supported) | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


